function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { freezeSys, toPlainObject } from 'contentful-sdk-core';
import copy from 'fast-copy';
import { wrapCollection } from '../common-utils';
import enhanceWithMethods from '../enhance-with-methods';
import { isDraft as _isDraft, isPublished as _isPublished, isUpdated as _isUpdated } from '../plain/checks';
import { wrapEditorInterface } from './editor-interface';
import { wrapSnapshot, wrapSnapshotCollection } from './snapshot';
import { omitAndDeleteField as _omitAndDeleteField } from '../methods/content-type';
/**
 * @private
 */
function createContentTypeApi(makeRequest) {
  const getParams = self => {
    const contentType = self.toPlainObject();
    return {
      raw: contentType,
      params: {
        spaceId: contentType.sys.space.sys.id,
        environmentId: contentType.sys.environment.sys.id,
        contentTypeId: contentType.sys.id
      }
    };
  };
  return {
    update: function update() {
      const _getParams = getParams(this),
        raw = _getParams.raw,
        params = _getParams.params;
      return makeRequest({
        entityType: 'ContentType',
        action: 'update',
        params,
        payload: raw
      }).then(data => wrapContentType(makeRequest, data));
    },
    delete: function _delete() {
      const _getParams2 = getParams(this),
        params = _getParams2.params;
      return makeRequest({
        entityType: 'ContentType',
        action: 'delete',
        params
      }).then(() => {
        // noop
      });
    },
    publish: function publish() {
      const _getParams3 = getParams(this),
        raw = _getParams3.raw,
        params = _getParams3.params;
      return makeRequest({
        entityType: 'ContentType',
        action: 'publish',
        params,
        payload: raw
      }).then(data => wrapContentType(makeRequest, data));
    },
    unpublish: function unpublish() {
      const _getParams4 = getParams(this),
        params = _getParams4.params;
      return makeRequest({
        entityType: 'ContentType',
        action: 'unpublish',
        params
      }).then(data => wrapContentType(makeRequest, data));
    },
    getEditorInterface: function getEditorInterface() {
      const _getParams5 = getParams(this),
        params = _getParams5.params;
      return makeRequest({
        entityType: 'EditorInterface',
        action: 'get',
        params
      }).then(data => wrapEditorInterface(makeRequest, data));
    },
    getSnapshots: function getSnapshots(query = {}) {
      const _getParams6 = getParams(this),
        params = _getParams6.params;
      return makeRequest({
        entityType: 'Snapshot',
        action: 'getManyForContentType',
        params: _objectSpread(_objectSpread({}, params), {}, {
          query
        })
      }).then(data => wrapSnapshotCollection(makeRequest, data));
    },
    getSnapshot: function getSnapshot(snapshotId) {
      const _getParams7 = getParams(this),
        params = _getParams7.params;
      return makeRequest({
        entityType: 'Snapshot',
        action: 'getForContentType',
        params: _objectSpread(_objectSpread({}, params), {}, {
          snapshotId
        })
      }).then(data => wrapSnapshot(makeRequest, data));
    },
    isPublished: function isPublished() {
      return _isPublished(this);
    },
    isUpdated: function isUpdated() {
      return _isUpdated(this);
    },
    isDraft: function isDraft() {
      return _isDraft(this);
    },
    omitAndDeleteField: function omitAndDeleteField(fieldId) {
      const _getParams8 = getParams(this),
        raw = _getParams8.raw,
        params = _getParams8.params;
      return _omitAndDeleteField(makeRequest, _objectSpread(_objectSpread({}, params), {}, {
        fieldId
      }), raw).then(data => wrapContentType(makeRequest, data));
    }
  };
}

/**
 * @private
 * @param makeRequest - function to make requests via an adapter
 * @param data - Raw content type data
 * @return Wrapped content type data
 */
export function wrapContentType(makeRequest, data) {
  const contentType = toPlainObject(copy(data));
  const contentTypeWithMethods = enhanceWithMethods(contentType, createContentTypeApi(makeRequest));
  return freezeSys(contentTypeWithMethods);
}

/**
 * @private
 */
export const wrapContentTypeCollection = wrapCollection(wrapContentType);